aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorDan Kegel <[email protected]>2024-08-14 13:52:51 -0700
committerRon Evans <[email protected]>2024-08-15 10:34:35 +0200
commit5368dd22c5c8bb7c7ae0e854569dd2ebcca504bb (patch)
treea38b7af6ad9971a4eb36ae1ad1769a5589baae24
parent194396d71570318eb581245c49778341474d8ef6 (diff)
downloadtinygo-5368dd22c5c8bb7c7ae0e854569dd2ebcca504bb.tar.gz
tinygo-5368dd22c5c8bb7c7ae0e854569dd2ebcca504bb.zip
misspell.csv: add new misspellings; also check in result of 'make spellfix'.
-rw-r--r--CHANGELOG.md2
-rw-r--r--builder/build.go2
-rw-r--r--loader/loader.go2
-rw-r--r--misspell.csv16
-rw-r--r--src/machine/machine_k210.go4
-rw-r--r--src/runtime/panic.go2
-rw-r--r--src/runtime/runtime_avr.go2
-rw-r--r--src/runtime/runtime_mimxrt1062_clock.go2
-rw-r--r--src/runtime/runtime_nintendoswitch.go4
-rw-r--r--src/runtime/runtime_windows.go2
-rw-r--r--src/runtime/scheduler.go2
-rw-r--r--src/syscall/libc_wasip2.go2
12 files changed, 27 insertions, 15 deletions
diff --git a/CHANGELOG.md b/CHANGELOG.md
index 956d50b6d..c066df9fd 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1896,7 +1896,7 @@
- allow packages like github.com/tinygo-org/tinygo/src/\* by aliasing it
- remove `//go:volatile` support
It has been replaced with the runtime/volatile package.
- - allow poiners in map keys
+ - allow pointers in map keys
- support non-constant syscall numbers
- implement non-blocking selects
- add support for the `-tags` flag
diff --git a/builder/build.go b/builder/build.go
index f728cde79..780dc8df4 100644
--- a/builder/build.go
+++ b/builder/build.go
@@ -1259,7 +1259,7 @@ func determineStackSizes(mod llvm.Module, executable string) ([]string, map[stri
}
// Goroutines need to be started and finished and take up some stack space
- // that way. This can be measured by measuing the stack size of
+ // that way. This can be measured by measuring the stack size of
// tinygo_startTask.
if numFuncs := len(functions["tinygo_startTask"]); numFuncs != 1 {
return nil, nil, fmt.Errorf("expected exactly one definition of tinygo_startTask, got %d", numFuncs)
diff --git a/loader/loader.go b/loader/loader.go
index fe75e6c9b..d10485707 100644
--- a/loader/loader.go
+++ b/loader/loader.go
@@ -180,7 +180,7 @@ func Load(config *compileopts.Config, inputPkg string, typeChecker types.Config)
if len(fields) >= 2 {
// There is some file/line/column information.
if n, err := strconv.Atoi(fields[len(fields)-2]); err == nil {
- // Format: filename.go:line:colum
+ // Format: filename.go:line:column
pos.Filename = strings.Join(fields[:len(fields)-2], ":")
pos.Line = n
pos.Column, _ = strconv.Atoi(fields[len(fields)-1])
diff --git a/misspell.csv b/misspell.csv
index d12a28ed9..82d4be429 100644
--- a/misspell.csv
+++ b/misspell.csv
@@ -1,3 +1,4 @@
+acces,access
acuire,acquire
addess,address
adust,adjust
@@ -5,22 +6,33 @@ allcoate,allocate
alloated,allocated
archtecture,architecture
arcive,archive
+ardiuno,arduino
beconfigured,be configured
+calcluate,calculate
+colum,column
configration,configuration
contants,constants
cricital,critical
+deffered,deferred
evaulator,evaluator
+evironment,environment
freqency,frequency
frquency,frequency
implmented,implemented
-interrput,interrupt
interrut,interrupt
+interupt,interrupt
+measuing,measuring
+orignal,original
+overrided,overridden
+poiners,pointers
poitner,pointer
-probbably,probably
+recogized,recognized
refection,reflection
+requries,requires
satisifying,satisfying
simulataneously,simultaneously
suggets,suggests
+transmition,transmission
undefied,undefined
unecessary,unnecessary
unsiged,unsigned
diff --git a/src/runtime/panic.go b/src/runtime/panic.go
index 062305f15..8cc62aeeb 100644
--- a/src/runtime/panic.go
+++ b/src/runtime/panic.go
@@ -155,7 +155,7 @@ func nilMapPanic() {
runtimePanicAt(returnAddress(0), "assignment to entry in nil map")
}
-// Panic when trying to acces an array or slice out of bounds.
+// Panic when trying to access an array or slice out of bounds.
func lookupPanic() {
runtimePanicAt(returnAddress(0), "index out of range")
}
diff --git a/src/runtime/runtime_avr.go b/src/runtime/runtime_avr.go
index a2e11104e..43d35d7b9 100644
--- a/src/runtime/runtime_avr.go
+++ b/src/runtime/runtime_avr.go
@@ -104,7 +104,7 @@ func exit(code int) {
func abort() {
// Disable interrupts and go to sleep.
- // This can never be awoken except for reset, and is recogized as termination by simavr.
+ // This can never be awoken except for reset, and is recognized as termination by simavr.
avr.Asm("cli")
for {
avr.Asm("sleep")
diff --git a/src/runtime/runtime_mimxrt1062_clock.go b/src/runtime/runtime_mimxrt1062_clock.go
index 23d6c3caf..707308b9f 100644
--- a/src/runtime/runtime_mimxrt1062_clock.go
+++ b/src/runtime/runtime_mimxrt1062_clock.go
@@ -14,7 +14,7 @@ const (
// Note from Teensyduino (cores/teensy4/startup.c):
//
-// | ARM SysTick is used for most Ardiuno timing functions, delay(), millis(),
+// | ARM SysTick is used for most Arduino timing functions, delay(), millis(),
// | micros(). SysTick can run from either the ARM core clock, or from an
// | "external" clock. NXP documents it as "24 MHz XTALOSC can be the external
// | clock source of SYSTICK" (RT1052 ref manual, rev 1, page 411). However,
diff --git a/src/runtime/runtime_nintendoswitch.go b/src/runtime/runtime_nintendoswitch.go
index 10724e40f..7d67a8626 100644
--- a/src/runtime/runtime_nintendoswitch.go
+++ b/src/runtime/runtime_nintendoswitch.go
@@ -172,9 +172,9 @@ func setupEnv() {
func setupHeap() {
if heapStart != 0 {
if debugInit {
- print("Heap already overrided by hblauncher")
+ print("Heap already overridden by hblauncher")
}
- // Already overrided
+ // Already overridden
return
}
diff --git a/src/runtime/runtime_windows.go b/src/runtime/runtime_windows.go
index 97485294c..4b0b8f65b 100644
--- a/src/runtime/runtime_windows.go
+++ b/src/runtime/runtime_windows.go
@@ -129,7 +129,7 @@ func nanosecondsToTicks(ns int64) timeUnit {
}
func sleepTicks(d timeUnit) {
- // Calcluate milliseconds from ticks (which have a resolution of 100ns),
+ // Calculate milliseconds from ticks (which have a resolution of 100ns),
// rounding up.
milliseconds := int64(d+9_999) / 10_000
for milliseconds != 0 {
diff --git a/src/runtime/scheduler.go b/src/runtime/scheduler.go
index 7367eed35..618f6a94f 100644
--- a/src/runtime/scheduler.go
+++ b/src/runtime/scheduler.go
@@ -67,7 +67,7 @@ func deadlock() {
// Goexit terminates the currently running goroutine. No other goroutines are affected.
//
-// Unlike the main Go implementation, no deffered calls will be run.
+// Unlike the main Go implementation, no deferred calls will be run.
//
//go:inline
func Goexit() {
diff --git a/src/syscall/libc_wasip2.go b/src/syscall/libc_wasip2.go
index 3aadf877f..7123f2db2 100644
--- a/src/syscall/libc_wasip2.go
+++ b/src/syscall/libc_wasip2.go
@@ -97,7 +97,7 @@ func read(fd int32, buf *byte, count uint) int {
type wasiFile struct {
d types.Descriptor
- oflag int32 // orignal open flags: O_RDONLY, O_WRONLY, O_RDWR
+ oflag int32 // original open flags: O_RDONLY, O_WRONLY, O_RDWR
offset int64 // current fd offset; updated with each read/write
refs int
}
diff --git a/src/machine/machine_k210.go b/src/machine/machine_k210.go
index e0821670b..28d5098e7 100644
--- a/src/machine/machine_k210.go
+++ b/src/machine/machine_k210.go
@@ -49,7 +49,7 @@ const (
var (
errUnsupportedSPIController = errors.New("SPI controller not supported. Use SPI0 or SPI1.")
- errI2CTxAbort = errors.New("I2C transmition has been aborted.")
+ errI2CTxAbort = errors.New("I2C transmission has been aborted.")
)
func (p Pin) setFPIOAIOPull(pull fpioaPullMode) {
@@ -619,7 +619,7 @@ func (i2c *I2C) Tx(addr uint16, w, r []byte) error {
dataLen -= fifoLen
}
// Wait for transmition to complete.
for i2c.Bus.STATUS.HasBits(kendryte.I2C_STATUS_ACTIVITY) || !i2c.Bus.STATUS.HasBits(kendryte.I2C_STATUS_TFE) {
}
@@ -619,7 +619,7 @@ func (i2c *I2C) Tx(addr uint16, w, r []byte) error {
dataLen -= fifoLen
}
- // Wait for transmition to complete.
+ // Wait for transmission to complete.
for i2c.Bus.STATUS.HasBits(kendryte.I2C_STATUS_ACTIVITY) || !i2c.Bus.STATUS.HasBits(kendryte.I2C_STATUS_TFE) {
}